@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,28 +16,43 @@
 package org.primefaces.component.api;
 
 /**
- * AjaxSource is the contract that needs to be implemented by components that fully implement all 
- * configuration options of PrimeFaces PPR
+ * AjaxSource is the contract that needs to be implemented by components that fully implement all configuration options of PrimeFaces PPR
  */
 public interface AjaxSource {
 
-	public String getOnstart();
-	
-	public String getOncomplete();
-	
-	public String getOnsuccess();
-	
-	public String getOnerror();
-	
-	public String getUpdate();
-	
-	public String getProcess();
-	
-	public boolean isGlobal();
-	
-	public boolean isAsync();
-    
+    public String getOnstart();
+
+    public String getOncomplete();
+
+    public String getOnsuccess();
+
+    public String getOnerror();
+
+    public String getUpdate();
+
+    public String getProcess();
+
+    public boolean isGlobal();
+
+    public boolean isAsync();
+
     public boolean isPartialSubmit();
-    
+
     public boolean isPartialSubmitSet();
+
+    public String getPartialSubmitFilter();
+
+    public boolean isResetValues();
+
+    public boolean isResetValuesSet();
+
+    public boolean isIgnoreAutoUpdate();
+
+    public boolean isAjaxified();
+
+    public String getDelay();
+
+    public int getTimeout();
+
+    public String getForm();
 }
