@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,17 +16,22 @@
 package org.primefaces.component.api;
 
 import java.util.List;
+import java.util.Map;
 import javax.faces.component.UIComponent;
 
 public interface UIOutcomeTarget {
- 
+
     public String getOutcome();
-    
+
     public boolean isIncludeViewParams();
-    
+
     public String getFragment();
-    
+
     public List<UIComponent> getChildren();
-    
+
+    public Map<String, List<String>> getParams();
+
     public String getHref();
+
+    public boolean isDisableClientWindow();
 }
