@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,24 +19,26 @@ import java.util.List;
 
 import javax.faces.view.facelets.ComponentConfig;
 import javax.faces.view.facelets.ComponentHandler;
+import javax.faces.view.facelets.MetaRule;
 import javax.faces.view.facelets.MetaRuleset;
 
-import org.primefaces.event.SelectEvent;
 import org.primefaces.facelets.MethodRule;
 
 public class AutoCompleteHandler extends ComponentHandler {
 
-	public AutoCompleteHandler(ComponentConfig config) {
-		super(config);
-	}
-	
-	@SuppressWarnings("unchecked")
-	protected MetaRuleset createMetaRuleset(Class type) { 
-		MetaRuleset metaRuleset = super.createMetaRuleset(type); 
-		
-		metaRuleset.addRule(new MethodRule("completeMethod", List.class, new Class[]{String.class}));
-		metaRuleset.addRule(new MethodRule("selectListener", null, new Class[]{SelectEvent.class}));
-		
-		return metaRuleset; 
-	} 
+    private static final MetaRule COMPLETE_METHOD
+            = new MethodRule("completeMethod", List.class, new Class[]{String.class});
+
+    public AutoCompleteHandler(ComponentConfig config) {
+        super(config);
+    }
+
+    @SuppressWarnings("unchecked")
+    protected MetaRuleset createMetaRuleset(Class type) {
+        MetaRuleset metaRuleset = super.createMetaRuleset(type);
+
+        metaRuleset.addRule(COMPLETE_METHOD);
+
+        return metaRuleset;
+    }
 }
