@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,23 +19,29 @@ import javax.faces.view.facelets.ComponentConfig;
 import javax.faces.view.facelets.ComponentHandler;
 import javax.faces.view.facelets.MetaRule;
 import javax.faces.view.facelets.MetaRuleset;
+import org.primefaces.component.api.UIData;
 
 import org.primefaces.facelets.MethodRule;
 
 public class DataTableHandler extends ComponentHandler {
 
-	public DataTableHandler(ComponentConfig config) {
-		super(config);
-	}
-	
-	@SuppressWarnings("unchecked")
-	protected MetaRuleset createMetaRuleset(Class type) { 
-		MetaRuleset metaRuleset = super.createMetaRuleset(type); 
-		Class[] paramList = new Class[]{Object.class, Object.class}; 
-		
-		MetaRule metaRule = new MethodRule("sortFunction", Integer.class, paramList); 
-		metaRuleset.addRule(metaRule);
-		
-		return metaRuleset; 
-	} 
+    private static final MetaRule SORT_FUNCTION
+            = new MethodRule("sortFunction", Integer.class, new Class[]{Object.class, Object.class});
+
+    private static final MetaRule DRAGGABLE_ROWS_FUNCTION
+            = new MethodRule("draggableRowsFunction", null, new Class[]{UIData.class});
+
+    public DataTableHandler(ComponentConfig config) {
+        super(config);
+    }
+
+    @SuppressWarnings("unchecked")
+    protected MetaRuleset createMetaRuleset(Class type) {
+        MetaRuleset metaRuleset = super.createMetaRuleset(type);
+
+        metaRuleset.addRule(SORT_FUNCTION);
+        metaRuleset.addRule(DRAGGABLE_ROWS_FUNCTION);
+
+        return metaRuleset;
+    }
 }
