@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,7 +22,10 @@ public enum DataTableFeatureKey {
     RESIZABLE_COLUMNS,
     DRAGGABLE_COLUMNS,
     ROW_EDIT,
+    CELL_EDIT,
     ROW_EXPAND,
     SCROLL,
-    SELECT;
+    SELECT,
+    DRAGGABLE_ROWS,
+    ADD_ROW;
 }
