@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,6 +17,7 @@ package org.primefaces.component.dnd;
 
 import javax.faces.view.facelets.ComponentConfig;
 import javax.faces.view.facelets.ComponentHandler;
+import javax.faces.view.facelets.MetaRule;
 import javax.faces.view.facelets.MetaRuleset;
 
 import org.primefaces.event.DragDropEvent;
@@ -24,17 +25,19 @@ import org.primefaces.facelets.MethodRule;
 
 public class DroppableHandler extends ComponentHandler {
 
-	public DroppableHandler(ComponentConfig config) {
-		super(config);
-	}
-	
-	@SuppressWarnings("unchecked")
-	protected MetaRuleset createMetaRuleset(Class type) { 
-		MetaRuleset metaRuleset = super.createMetaRuleset(type); 
-		Class[] eventClasses = new Class[]{DragDropEvent.class};
-		
-		metaRuleset.addRule(new MethodRule("dropListener", null, eventClasses));
-		
-		return metaRuleset;  
-	}
-}
\ No newline at end of file
+    private static final MetaRule DROP_LISTENER
+            = new MethodRule("dropListener", null, new Class[]{DragDropEvent.class});
+
+    public DroppableHandler(ComponentConfig config) {
+        super(config);
+    }
+
+    @SuppressWarnings("unchecked")
+    protected MetaRuleset createMetaRuleset(Class type) {
+        MetaRuleset metaRuleset = super.createMetaRuleset(type);
+
+        metaRuleset.addRule(DROP_LISTENER);
+
+        return metaRuleset;
+    }
+}
