@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,5 +19,7 @@ public enum ExporterType {
     XLS,
     PDF,
     CSV,
-    XML
+    XML,
+    XLSX,
+    XLSXSTREAM
 }
