@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,10 +15,9 @@
  */
 package org.primefaces.component.fileupload;
 
-import java.util.List;
-
 import javax.faces.view.facelets.ComponentConfig;
 import javax.faces.view.facelets.ComponentHandler;
+import javax.faces.view.facelets.MetaRule;
 import javax.faces.view.facelets.MetaRuleset;
 
 import org.primefaces.event.FileUploadEvent;
@@ -26,17 +25,19 @@ import org.primefaces.facelets.MethodRule;
 
 public class FileUploadHandler extends ComponentHandler {
 
-	public FileUploadHandler(ComponentConfig config) {
-		super(config);
-	}
-	
-	@SuppressWarnings("unchecked")
-	protected MetaRuleset createMetaRuleset(Class type) { 
-		MetaRuleset metaRuleset = super.createMetaRuleset(type); 
-		Class[] fileUploadEventClass = new Class[]{FileUploadEvent.class};
-		
-		metaRuleset.addRule(new MethodRule("fileUploadListener", List.class, fileUploadEventClass));
-		
-		return metaRuleset; 
-	} 
-}
\ No newline at end of file
+    private static final MetaRule FILE_UPLOAD_LISTENER
+            = new MethodRule("fileUploadListener", null, new Class[]{FileUploadEvent.class});
+
+    public FileUploadHandler(ComponentConfig config) {
+        super(config);
+    }
+
+    @SuppressWarnings("unchecked")
+    protected MetaRuleset createMetaRuleset(Class type) {
+        MetaRuleset metaRuleset = super.createMetaRuleset(type);
+
+        metaRuleset.addRule(FILE_UPLOAD_LISTENER);
+
+        return metaRuleset;
+    }
+}
