@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,26 +17,31 @@ package org.primefaces.component.media.player;
 
 public class QuickTimePlayer implements MediaPlayer {
 
-	private final static String[] supportedTypes = new String[]{"aif","aiff","aac","au","bmp","gsm","mov","mid","midi","mpg","mpeg",
-																"mp4","m4a","psd","qt","qtif","qif","qti","snd","tif","tiff","wav","3g2","3pg"};
-	
-	public String getClassId() {
-		return "clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B";
-	}
+    private final static String[] SUPPORTED_TYPES = new String[] { "aif", "aiff", "aac", "au", "bmp", "gsm", "mov", "mid", "midi", "mpg", "mpeg",
+        "mp4", "m4a", "psd", "qt", "qtif", "qif", "qti", "snd", "tif", "tiff", "wav", "3g2", "3pg" };
 
-	public String getCodebase() {
-		return "http://www.apple.com/qtactivex/qtplugin.cab";
-	}
-	
-	public String getSourceParam() {
-		return "src";
-	}
-
-	public String getType() {
-		return null;
-	}
-	
-    public String[] getSupportedTypes() {
-        return supportedTypes;
+    @Override
+    public String getClassId() {
+        return "clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B";
     }
-}
\ No newline at end of file
+
+    @Override
+    public String getCodebase() {
+        return "http://www.apple.com/qtactivex/qtplugin.cab";
+    }
+
+    @Override
+    public String getSourceParam() {
+        return "src";
+    }
+
+    @Override
+    public String getType() {
+        return null;
+    }
+
+    @Override
+    public String[] getSupportedTypes() {
+        return SUPPORTED_TYPES;
+    }
+}
