@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,25 +17,30 @@ package org.primefaces.component.media.player;
 
 public class WindowsPlayer implements MediaPlayer {
 
-	private final static String[] supportedTypes = new String[]{"asx", "asf", "avi", "wma", "wmv"};
-	
-	public String getClassId() {
-		return "clsid:6BF52A52-394A-11D3-B153-00C04F79FAA6";
-	}
+    private static final String[] SUPPORTED_TYPES = new String[] { "asx", "asf", "avi", "wma", "wmv" };
 
-	public String getCodebase() {
-		return "http://activex.microsoft.com/activex/controls/mplayer/en/nsmp2inf.cab#Version=6,4,7,1112";
-	}
-	
-	public String getSourceParam() {
-		return "url";
-	}
-
-	public String getType() {
-		return "application/x-mplayer2";
-	}
-	
-    public String[] getSupportedTypes() {
-        return supportedTypes;
+    @Override
+    public String getClassId() {
+        return "clsid:6BF52A52-394A-11D3-B153-00C04F79FAA6";
     }
-}
\ No newline at end of file
+
+    @Override
+    public String getCodebase() {
+        return "http://activex.microsoft.com/activex/controls/mplayer/en/nsmp2inf.cab#Version=6,4,7,1112";
+    }
+
+    @Override
+    public String getSourceParam() {
+        return "url";
+    }
+
+    @Override
+    public String getType() {
+        return "application/x-mplayer2";
+    }
+
+    @Override
+    public String[] getSupportedTypes() {
+        return SUPPORTED_TYPES;
+    }
+}
