@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,22 +17,26 @@ package org.primefaces.component.poll;
 
 import javax.faces.view.facelets.ComponentConfig;
 import javax.faces.view.facelets.ComponentHandler;
+import javax.faces.view.facelets.MetaRule;
 import javax.faces.view.facelets.MetaRuleset;
 
 import org.primefaces.facelets.MethodRule;
 
 public class PollHandler extends ComponentHandler {
 
-	public PollHandler(ComponentConfig config) {
-		super(config);
-	}
+    private static final MetaRule LISTENER
+            = new MethodRule("listener", null, new Class[0]);
 
-	@SuppressWarnings("unchecked")
-	protected MetaRuleset createMetaRuleset(Class type) {
-		MetaRuleset metaRuleset = super.createMetaRuleset(type);
+    public PollHandler(ComponentConfig config) {
+        super(config);
+    }
 
-		metaRuleset.addRule(new MethodRule("listener", null, new Class[0]));
+    @SuppressWarnings("unchecked")
+    protected MetaRuleset createMetaRuleset(Class type) {
+        MetaRuleset metaRuleset = super.createMetaRuleset(type);
 
-		return metaRuleset;
-	}
-}
\ No newline at end of file
+        metaRuleset.addRule(LISTENER);
+
+        return metaRuleset;
+    }
+}
