@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,25 +17,24 @@ package org.primefaces.component.terminal;
 
 import javax.faces.view.facelets.ComponentConfig;
 import javax.faces.view.facelets.ComponentHandler;
-import javax.faces.view.facelets.MetaRule;
 import javax.faces.view.facelets.MetaRuleset;
 
 import org.primefaces.facelets.MethodRule;
 
 public class TerminalHandler extends ComponentHandler {
 
-	public TerminalHandler(ComponentConfig config) {
-		super(config);
-	}
-	
-	@SuppressWarnings("unchecked")
-	protected MetaRuleset createMetaRuleset(Class type) { 
-		MetaRuleset metaRuleset = super.createMetaRuleset(type); 
-		Class[] paramList = new Class[]{String.class, String[].class}; 
-		
-		MetaRule metaRule = new MethodRule("commandHandler", String.class, paramList); 
-		metaRuleset.addRule(metaRule);
-		
-		return metaRuleset; 
-	} 
+    private static final MethodRule COMMAND_HANDLER
+            = new MethodRule("commandHandler", String.class, new Class[]{String.class, String[].class});
+
+    public TerminalHandler(ComponentConfig config) {
+        super(config);
+    }
+
+    @SuppressWarnings("unchecked")
+    protected MetaRuleset createMetaRuleset(Class type) {
+        MetaRuleset metaRuleset = super.createMetaRuleset(type);
+        metaRuleset.addRule(COMMAND_HANDLER);
+
+        return metaRuleset;
+    }
 }
