@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,27 +18,21 @@ package org.primefaces.component.themeswitcher;
 import java.io.IOException;
 
 import javax.faces.context.FacesContext;
-import javax.faces.context.ResponseWriter;
 import org.primefaces.component.selectonemenu.SelectOneMenu;
 import org.primefaces.component.selectonemenu.SelectOneMenuRenderer;
 import org.primefaces.util.WidgetBuilder;
 
 public class ThemeSwitcherRenderer extends SelectOneMenuRenderer {
- 
+
     @Override
-	protected void encodeScript(FacesContext context, SelectOneMenu menu) throws IOException {
-		ResponseWriter writer = context.getResponseWriter();
+    protected void encodeScript(FacesContext context, SelectOneMenu menu) throws IOException {
         ThemeSwitcher ts = (ThemeSwitcher) menu;
         String clientId = ts.getClientId(context);
         WidgetBuilder wb = getWidgetBuilder(context);
-        wb.widget("ThemeSwitcher", ts.resolveWidgetVar(), clientId, true)
+        wb.initWithDomReady("ThemeSwitcher", ts.resolveWidgetVar(), clientId)
                 .attr("effect", ts.getEffect(), null)
                 .attr("effectSpeed", ts.getEffectSpeed(), null);
-        
-        encodeClientBehaviors(context, menu, wb);
-        
-        startScript(writer, clientId);
-        writer.write(wb.build());
-        endScript(writer);
-	}
-}
\ No newline at end of file
+
+        wb.finish();
+    }
+}
