@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,6 +17,7 @@ package org.primefaces.component.wizard;
 
 import javax.faces.view.facelets.ComponentConfig;
 import javax.faces.view.facelets.ComponentHandler;
+import javax.faces.view.facelets.MetaRule;
 import javax.faces.view.facelets.MetaRuleset;
 
 import org.primefaces.event.FlowEvent;
@@ -24,18 +25,19 @@ import org.primefaces.facelets.MethodRule;
 
 public class WizardHandler extends ComponentHandler {
 
-	public WizardHandler(ComponentConfig config) {
-		super(config);
-	}
-	
-	@SuppressWarnings("unchecked")
-	protected MetaRuleset createMetaRuleset(Class type) { 
-		MetaRuleset metaRuleset = super.createMetaRuleset(type);
-		
-		Class[] eventClasses = new Class[]{FlowEvent.class};
-		
-		metaRuleset.addRule(new MethodRule("flowListener", String.class, eventClasses));
-		
-		return metaRuleset;  
-	} 
-}
\ No newline at end of file
+    private static final MetaRule FLOW_LISTENER
+            = new MethodRule("flowListener", String.class, new Class[]{FlowEvent.class});
+
+    public WizardHandler(ComponentConfig config) {
+        super(config);
+    }
+
+    @SuppressWarnings("unchecked")
+    protected MetaRuleset createMetaRuleset(Class type) {
+        MetaRuleset metaRuleset = super.createMetaRuleset(type);
+
+        metaRuleset.addRule(FLOW_LISTENER);
+
+        return metaRuleset;
+    }
+}
