@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,7 +22,12 @@ import javax.faces.context.PartialViewContextFactory;
 public class PrimePartialViewContextFactory extends PartialViewContextFactory {
 
     private PartialViewContextFactory parent;
-    
+
+    // #6212 - don't remove it
+    public PrimePartialViewContextFactory() {
+
+    }
+
     public PrimePartialViewContextFactory(PartialViewContextFactory parent) {
         this.parent = parent;
     }
@@ -35,7 +40,7 @@ public class PrimePartialViewContextFactory extends PartialViewContextFactory {
     @Override
     public PartialViewContext getPartialViewContext(FacesContext fc) {
         PartialViewContext parentContext = getWrapped().getPartialViewContext(fc);
-        
+
         return new PrimePartialViewContext(parentContext);
     }
-}
\ No newline at end of file
+}
