@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,31 +17,18 @@ package org.primefaces.event;
 
 import javax.faces.component.UIComponent;
 import javax.faces.component.behavior.Behavior;
-import javax.faces.event.AjaxBehaviorListener;
-import javax.faces.event.FacesListener;
 import org.primefaces.component.api.UIColumn;
-import org.primefaces.component.column.Column;
 
 public class ColumnResizeEvent extends ResizeEvent {
 
-	private UIColumn column;
-	
-	public ColumnResizeEvent(UIComponent component, Behavior behavior, int width, int height, UIColumn column) {
-		super(component, behavior, width, height);
-		this.column = column;
-	}
+    private UIColumn column;
 
-	@Override
-	public boolean isAppropriateListener(FacesListener faceslistener) {
-        return (faceslistener instanceof AjaxBehaviorListener);
-	}
-
-	@Override
-	public void processListener(FacesListener faceslistener) {
-		((AjaxBehaviorListener) faceslistener).processAjaxBehavior(this);
-	}
+    public ColumnResizeEvent(UIComponent component, Behavior behavior, int width, int height, UIColumn column) {
+        super(component, behavior, width, height);
+        this.column = column;
+    }
 
     public UIColumn getColumn() {
         return column;
     }
-}
\ No newline at end of file
+}
