@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,12 +17,9 @@ package org.primefaces.event;
 
 import javax.faces.component.UIComponent;
 import javax.faces.component.behavior.Behavior;
-import javax.faces.event.AjaxBehaviorEvent;
-import javax.faces.event.AjaxBehaviorListener;
-import javax.faces.event.FacesListener;
 import javax.faces.event.PhaseId;
 
-public class RowEditEvent extends AjaxBehaviorEvent {
+public class RowEditEvent extends AbstractAjaxBehaviorEvent {
 
     private Object object;
 
@@ -31,16 +28,6 @@ public class RowEditEvent extends AjaxBehaviorEvent {
         this.object = object;
     }
 
-	@Override
-	public boolean isAppropriateListener(FacesListener faceslistener) {
-		return (faceslistener instanceof AjaxBehaviorListener);
-	}
-
-	@Override
-	public void processListener(FacesListener faceslistener) {
-		((AjaxBehaviorListener) faceslistener).processAjaxBehavior(this);
-	}
-
     public Object getObject() {
         return object;
     }
@@ -49,4 +36,4 @@ public class RowEditEvent extends AjaxBehaviorEvent {
     public PhaseId getPhaseId() {
         return PhaseId.INVOKE_APPLICATION;
     }
-}
\ No newline at end of file
+}
