@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,30 +17,17 @@ package org.primefaces.event;
 
 import javax.faces.component.UIComponent;
 import javax.faces.component.behavior.Behavior;
-import javax.faces.event.AjaxBehaviorEvent;
-import javax.faces.event.AjaxBehaviorListener;
-import javax.faces.event.FacesListener;
 
-public class SlideEndEvent extends AjaxBehaviorEvent {
+public class SlideEndEvent extends AbstractAjaxBehaviorEvent {
 
     private int value;
 
-	public SlideEndEvent(UIComponent component, Behavior behavior, int value) {
-		super(component , behavior);
+    public SlideEndEvent(UIComponent component, Behavior behavior, int value) {
+        super(component, behavior);
         this.value = value;
-	}
-
-	@Override
-	public boolean isAppropriateListener(FacesListener faceslistener) {
-		return (faceslistener instanceof AjaxBehaviorListener);
-	}
-
-	@Override
-	public void processListener(FacesListener faceslistener) {
-		((AjaxBehaviorListener) faceslistener).processAjaxBehavior(this);
-	}
+    }
 
     public int getValue() {
         return value;
     }
-}
\ No newline at end of file
+}
