@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,46 +17,37 @@ package org.primefaces.event;
 
 import javax.faces.component.UIComponent;
 import javax.faces.component.behavior.Behavior;
-import javax.faces.event.AjaxBehaviorEvent;
-import javax.faces.event.AjaxBehaviorListener;
-import javax.faces.event.FacesListener;
 
 import org.primefaces.model.Visibility;
 
-public class ToggleEvent extends AjaxBehaviorEvent {
-	
-    /** Visibility status */
-	private Visibility visibility;
-    
-    /** Related data if available */
+public class ToggleEvent extends AbstractAjaxBehaviorEvent {
+
+    /**
+     * Visibility status
+     */
+    private Visibility visibility;
+
+    /**
+     * Related data if available
+     */
     private Object data;
-	
-	public ToggleEvent(UIComponent component, Behavior behavior, Visibility visibility) {
-		super(component, behavior);
-		this.visibility = visibility;
-	}
-    
+
+    public ToggleEvent(UIComponent component, Behavior behavior, Visibility visibility) {
+        super(component, behavior);
+        this.visibility = visibility;
+    }
+
     public ToggleEvent(UIComponent component, Behavior behavior, Visibility visibility, Object data) {
-		super(component, behavior);
-		this.visibility = visibility;
+        super(component, behavior);
+        this.visibility = visibility;
         this.data = data;
-	}
+    }
 
-	@Override
-	public boolean isAppropriateListener(FacesListener faceslistener) {
-		return (faceslistener instanceof AjaxBehaviorListener);
-	}
-
-	@Override
-	public void processListener(FacesListener faceslistener) {
-		((AjaxBehaviorListener) faceslistener).processAjaxBehavior(this);
-	}
-	
-	public Visibility getVisibility() {
-		return visibility;
-	}
+    public Visibility getVisibility() {
+        return visibility;
+    }
 
     public Object getData() {
         return data;
     }
-}
\ No newline at end of file
+}
