@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,30 +17,17 @@ package org.primefaces.event;
 
 import javax.faces.component.UIComponent;
 import javax.faces.component.behavior.Behavior;
-import javax.faces.event.AjaxBehaviorEvent;
-import javax.faces.event.AjaxBehaviorListener;
-import javax.faces.event.FacesListener;
 
-public class ToggleSelectEvent extends AjaxBehaviorEvent {
-	
-	private boolean selected;
-    
-	public ToggleSelectEvent(UIComponent component, Behavior behavior, boolean selected) {
-		super(component, behavior);
-		this.selected = selected;
-	}
-    
-	@Override
-	public boolean isAppropriateListener(FacesListener faceslistener) {
-		return (faceslistener instanceof AjaxBehaviorListener);
-	}
+public class ToggleSelectEvent extends AbstractAjaxBehaviorEvent {
 
-	@Override
-	public void processListener(FacesListener faceslistener) {
-		((AjaxBehaviorListener) faceslistener).processAjaxBehavior(this);
-	}
+    private boolean selected;
+
+    public ToggleSelectEvent(UIComponent component, Behavior behavior, boolean selected) {
+        super(component, behavior);
+        this.selected = selected;
+    }
 
     public boolean isSelected() {
         return selected;
     }
-}
\ No newline at end of file
+}
