@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,35 +18,22 @@ package org.primefaces.event;
 import java.util.List;
 import javax.faces.component.UIComponent;
 import javax.faces.component.behavior.Behavior;
-import javax.faces.event.AjaxBehaviorEvent;
-import javax.faces.event.AjaxBehaviorListener;
-import javax.faces.event.FacesListener;
 
-public class TransferEvent extends AjaxBehaviorEvent {
+public class TransferEvent extends AbstractAjaxBehaviorEvent {
 
     private List<?> items;
     private boolean add;
 
-	public TransferEvent(UIComponent component, Behavior behavior, List<?> items, boolean add) {
-		super(component, behavior);
+    public TransferEvent(UIComponent component, Behavior behavior, List<?> items, boolean add) {
+        super(component, behavior);
         this.items = items;
         this.add = add;
-	}
-
-	@Override
-	public boolean isAppropriateListener(FacesListener faceslistener) {
-		return (faceslistener instanceof AjaxBehaviorListener);
-	}
-
-	@Override
-	public void processListener(FacesListener faceslistener) {
-        ((AjaxBehaviorListener) faceslistener).processAjaxBehavior(this);
-	}
+    }
 
     public boolean isAdd() {
         return add;
     }
-    
+
     public boolean isRemove() {
         return !add;
     }
@@ -54,4 +41,4 @@ public class TransferEvent extends AjaxBehaviorEvent {
     public List<?> getItems() {
         return items;
     }
-}
\ No newline at end of file
+}
