@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,30 +17,18 @@ package org.primefaces.event.data;
 
 import javax.faces.component.UIComponent;
 import javax.faces.component.behavior.Behavior;
-import javax.faces.event.AjaxBehaviorEvent;
-import javax.faces.event.AjaxBehaviorListener;
-import javax.faces.event.FacesListener;
+import org.primefaces.event.AbstractAjaxBehaviorEvent;
 
-public class PageEvent extends AjaxBehaviorEvent {
+public class PageEvent extends AbstractAjaxBehaviorEvent {
 
-	private int page;
-	
-	public PageEvent(UIComponent component, Behavior behavior, int page) {
-		super(component, behavior);
-		this.page = page;
-	}
+    private int page;
 
-	@Override
-	public boolean isAppropriateListener(FacesListener faceslistener) {
-		return (faceslistener instanceof AjaxBehaviorListener);
-	}
-
-	@Override
-	public void processListener(FacesListener faceslistener) {
-		((AjaxBehaviorListener) faceslistener).processAjaxBehavior(this);
-	}
+    public PageEvent(UIComponent component, Behavior behavior, int page) {
+        super(component, behavior);
+        this.page = page;
+    }
 
     public int getPage() {
         return page;
     }
-}
\ No newline at end of file
+}
