@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,24 +15,26 @@
  */
 package org.primefaces.model;
 
+import java.util.Locale;
 import javax.el.MethodExpression;
 import javax.el.ValueExpression;
 import org.primefaces.component.api.DynamicColumn;
 
 public class DynamicChainedPropertyComparator extends BeanPropertyComparator {
-    
+
     private DynamicColumn column;
-    
-    public DynamicChainedPropertyComparator(DynamicColumn column, ValueExpression sortBy, String var, SortOrder sortOrder, MethodExpression sortFunction) {
-        super(sortBy, var, sortOrder, sortFunction);
+
+    public DynamicChainedPropertyComparator(DynamicColumn column, ValueExpression sortBy, String var, SortOrder sortOrder, MethodExpression sortFunction,
+            boolean caseSensitiveSort, Locale locale, int nullSortOrder) {
+        super(sortBy, var, sortOrder, sortFunction, caseSensitiveSort, locale, nullSortOrder);
         this.column = column;
-    } 
-    
+    }
+
     @SuppressWarnings("unchecked")
     @Override
     public int compare(Object obj1, Object obj2) {
         column.applyStatelessModel();
-        
+
         return super.compare(obj1, obj2);
     }
 }
