@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,13 +18,15 @@ package org.primefaces.model;
 import java.io.InputStream;
 
 public interface StreamedContent {
-	
-	public String getName();
 
-	public InputStream getStream();
-	
-	public String getContentType();
-    
+    public String getName();
+
+    public InputStream getStream();
+
+    public String getContentType();
+
     public String getContentEncoding();
-	
+
+    public Integer getContentLength();
+
 }
