@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,30 +18,42 @@ package org.primefaces.model;
 import java.util.List;
 
 public interface TreeNode {
-		
-	public String getType();
 
-	public Object getData();
-	
-	public List<TreeNode> getChildren();
-	
-	public TreeNode getParent();
-	
-	public void setParent(TreeNode treeNode);
+    public String getType();
 
-	public boolean isExpanded();
-	
-	public void setExpanded(boolean expanded);
+    public void setType(String type);
 
-	public int getChildCount();
-	
-	public boolean isLeaf();
+    public Object getData();
+
+    public List<TreeNode> getChildren();
+
+    public TreeNode getParent();
+
+    public void setParent(TreeNode treeNode);
+
+    public boolean isExpanded();
+
+    public void setExpanded(boolean expanded);
+
+    public int getChildCount();
+
+    public boolean isLeaf();
 
     public boolean isSelected();
 
     public void setSelected(boolean value);
-    
+
     public boolean isSelectable();
-	
-	public void setSelectable(boolean selectable);
-}
\ No newline at end of file
+
+    public void setSelectable(boolean selectable);
+
+    public boolean isPartialSelected();
+
+    public void setPartialSelected(boolean value);
+
+    public void setRowKey(String rowKey);
+
+    public String getRowKey();
+
+    public void clearParent();
+}
