@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,13 +15,15 @@
  */
 package org.primefaces.model.chart;
 
-import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.List;
 
-public class BubbleChartModel extends ChartModel implements Serializable {
+public class BubbleChartModel extends CartesianChartModel {
 
     private List<BubbleChartSeries> data;
+    private boolean bubbleGradients = false;
+    private double bubbleAlpha = 1.0;
+    private boolean showLabels = true;
 
     public BubbleChartModel() {
         data = new ArrayList<BubbleChartSeries>();
@@ -30,7 +32,7 @@ public class BubbleChartModel extends ChartModel implements Serializable {
     public BubbleChartModel(List<BubbleChartSeries> data) {
         this.data = data;
     }
-    
+
     public List<BubbleChartSeries> getData() {
         return data;
     }
@@ -38,17 +40,41 @@ public class BubbleChartModel extends ChartModel implements Serializable {
     public void setData(List<BubbleChartSeries> data) {
         this.data = data;
     }
-    
-    public void add(BubbleChartSeries bubble){
+
+    public void add(BubbleChartSeries bubble) {
         this.data.add(bubble);
     }
-    
+
     @Deprecated
-    public void addBubble(BubbleChartSeries bubble){
+    public void addBubble(BubbleChartSeries bubble) {
         this.data.add(bubble);
     }
 
     public void clear() {
         this.data.clear();
     }
-}
\ No newline at end of file
+
+    public boolean isBubbleGradients() {
+        return bubbleGradients;
+    }
+
+    public void setBubbleGradients(boolean bubbleGradients) {
+        this.bubbleGradients = bubbleGradients;
+    }
+
+    public double getBubbleAlpha() {
+        return bubbleAlpha;
+    }
+
+    public void setBubbleAlpha(double bubbleAlpha) {
+        this.bubbleAlpha = bubbleAlpha;
+    }
+
+    public boolean isShowLabels() {
+        return showLabels;
+    }
+
+    public void setShowLabels(boolean showLabels) {
+        this.showLabels = showLabels;
+    }
+}
