@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,14 +15,15 @@
  */
 package org.primefaces.model.chart;
 
-import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.List;
 
-public class OhlcChartModel extends ChartModel implements Serializable {
+public class OhlcChartModel extends CartesianChartModel {
 
     private List<OhlcChartSeries> data;
 
+    private boolean candleStick;
+
     public OhlcChartModel() {
         data = new ArrayList<OhlcChartSeries>();
     }
@@ -30,7 +31,7 @@ public class OhlcChartModel extends ChartModel implements Serializable {
     public OhlcChartModel(List<OhlcChartSeries> data) {
         this.data = data;
     }
-    
+
     public List<OhlcChartSeries> getData() {
         return data;
     }
@@ -38,17 +39,26 @@ public class OhlcChartModel extends ChartModel implements Serializable {
     public void setData(List<OhlcChartSeries> data) {
         this.data = data;
     }
-    
-    public void add(OhlcChartSeries ohlc){
+
+    public void add(OhlcChartSeries ohlc) {
         this.data.add(ohlc);
     }
-    
+
     @Deprecated
-    public void addRecord(OhlcChartSeries ohlc){
+    public void addRecord(OhlcChartSeries ohlc) {
         this.data.add(ohlc);
     }
-    
+
     public void clear() {
         this.data.clear();
     }
-}
\ No newline at end of file
+
+    public boolean isCandleStick() {
+        return candleStick;
+    }
+
+    public void setCandleStick(boolean candleStick) {
+        this.candleStick = candleStick;
+    }
+
+}
