@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,7 +15,9 @@
  */
 package org.primefaces.model.filter;
 
+import java.util.Locale;
+
 public interface FilterConstraint {
 
-    public boolean applies(String value, String filter);
+    public boolean applies(Object value, Object filter, Locale locale);
 }
