@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,9 +15,23 @@
  */
 package org.primefaces.model.filter;
 
+import java.util.Locale;
+import org.primefaces.util.Constants;
+
 public class StartsWithFilterConstraint implements FilterConstraint {
 
-    public boolean applies(String value, String filter) {
-        return value.toLowerCase().startsWith(filter.toLowerCase());
+    @Override
+    public boolean applies(Object value, Object filter, Locale locale) {
+        String filterText = (filter == null) ? null : filter.toString().trim().toLowerCase(locale);
+
+        if (filterText == null || filterText.equals(Constants.EMPTY_STRING)) {
+            return true;
+        }
+
+        if (value == null) {
+            return false;
+        }
+
+        return value.toString().toLowerCase(locale).startsWith(filterText);
     }
-}
\ No newline at end of file
+}
