@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,20 +15,28 @@
  */
 package org.primefaces.push;
 
+import org.atmosphere.cpr.MetaBroadcaster;
+
 /**
  * Factory for retrieving {@link PushContext}
+ *
+ * @deprecated With PrimeFaces 4.1 and up, it is recommended to use {@link EventBus}
  */
 public class PushContextFactory {
 
-    private static final PushContextFactory p = new PushContextFactory();
+    private static PushContextFactory p;
     private final PushContext pushContext;
+    private final MetaBroadcaster metaBroadcaster;
 
-    private PushContextFactory() {
-        pushContext = new PushContextImpl();
+    protected PushContextFactory(MetaBroadcaster metaBroadcaster) {
+        this.metaBroadcaster = metaBroadcaster;
+        pushContext = new PushContextImpl(this.metaBroadcaster);
+        p = this;
     }
 
     /**
      * Return the default factory
+     *
      * @return the default factory
      */
     public final static PushContextFactory getDefault() {
@@ -37,9 +45,10 @@ public class PushContextFactory {
 
     /**
      * Retrieve a {@link PushContext}
+     *
      * @return
      */
-    public PushContext getPushContext(){
+    public PushContext getPushContext() {
         return pushContext;
     }
 
