@@ -1,5 +1,5 @@
-/*
- * Copyright 2009-2012 Prime Teknoloji.
+/**
+ * Copyright 2009-2018 PrimeTek.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,22 +15,37 @@
  */
 package org.primefaces.webapp;
 
+import org.primefaces.util.Jsf23Helper;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+
 import javax.faces.event.AbortProcessingException;
 import javax.faces.event.SystemEvent;
 import javax.faces.event.SystemEventListener;
-import org.primefaces.util.Constants;
+
+import org.primefaces.config.PrimeConfiguration;
+import org.primefaces.config.StartupPrimeConfiguration;
 
 public class PostConstructApplicationEventListener implements SystemEventListener {
 
     private final static Logger logger = Logger.getLogger(PostConstructApplicationEventListener.class.getName());
 
+    @Override
     public boolean isListenerForSource(Object source) {
         return true;
     }
 
+    @Override
     public void processEvent(SystemEvent event) throws AbortProcessingException {
-        logger.log(Level.INFO, "Running on PrimeFaces {0}", Constants.VERSION);
+        // temp manually instantiate startup config as the default config is not available yet
+        PrimeConfiguration config = new StartupPrimeConfiguration();
+
+        logger.log(Level.INFO,
+                "Running on PrimeFaces {0}",
+                config.getBuildVersion());
+        
+        if (config.isAtLeastJSF23()) {
+            Jsf23Helper.addSearchKeywordResolvers();
+        }
     }
 }
