@@ -499,7 +499,7 @@ $.extend(Keypad.prototype, {
 	/* Handle keystrokes.
 	   @param  e  (event) the key event */
 	_doKeyDown: function(e) {
-		if (e.keyCode == 9) { // Tab out
+		if (e.which == 9) { // Tab out
 			$.keypad.mainDiv.stop(true, true);
 			$.keypad._hideKeypad(null, '');
 		}
@@ -512,9 +512,9 @@ $.extend(Keypad.prototype, {
 			return;
 		}
 		var target = $(event.target);
-		if (!target.parents().andSelf().is('#' + $.keypad._mainDivId) &&
+		if (!target.parents().addBack().is('#' + $.keypad._mainDivId) &&
 				!target.hasClass($.keypad.markerClassName) &&
-				!target.parents().andSelf().hasClass($.keypad._triggerClass) &&
+				!target.parents().addBack().hasClass($.keypad._triggerClass) &&
 				$.keypad._keypadShowing) {
 			$.keypad._hideKeypad(null, '');
 		}
@@ -902,12 +902,11 @@ $(function() {
         else
             this.cfg.layout = PrimeFaces.widget.KeyboardUtils.getPresetLayout(this.cfg.layoutName);
 
-        this.jq.keypad(this.cfg);
+        this.cfg.beforeShow = function(div, inst) {
+            $(div).addClass('ui-input-overlay').css('z-index', ++PrimeFaces.zindex);
+        };
 
-        //Client Behaviors
-        if(this.cfg.behaviors) {
-            PrimeFaces.attachBehaviors(this.jq, this.cfg.behaviors);
-        }
+        this.jq.keypad(this.cfg);
 
         //Visuals
         PrimeFaces.skinInput(this.jq);
